==> 0.0.2.tar.gz: lib/models/v2_tim_group_member_full_info.dart <==
import 'package:flutter/cupertino.dart';

/// V2TimGroupMemberFullInfo
///
/// {@category Models}
///
class V2TimGroupMemberFullInfo {
  String userID;
  int role;
  int muteUntil;
  int joinTime;
  Map<String, String> customInfo;
  String nickName;
  String nameCard;
  String friendRemark;
  String faceUrl;

  V2TimGroupMemberFullInfo({
    @required this.userID,
    this.role,
    this.muteUntil,
    this.joinTime,
    this.customInfo,
    this.nickName,
    this.nameCard,
    this.friendRemark,
    this.faceUrl,
  });

  V2TimGroupMemberFullInfo.fromJson(Map<String, dynamic> json) {
    userID = json['userID'];
    role = json['role'];
    muteUntil = json['muteUntil'];
    joinTime = json['joinTime'];
    customInfo = json['customInfo'] == null
        ? new Map<String, String>()
        : Map<String, String>.from(json['customInfo']);
    nickName = json['nickName'];
    nameCard = json['nameCard'];
    friendRemark = json['friendRemark'];
    faceUrl = json['faceUrl'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['userID'] = this.userID;
    data['role'] = this.role;
    data['muteUntil'] = this.muteUntil;
    data['joinTime'] = this.joinTime;
    data['customInfo'] = this.customInfo;
    data['nickName'] = this.nickName;
    data['nameCard'] = this.nameCard;
    data['friendRemark'] = this.friendRemark;
    data['faceUrl'] = this.faceUrl;
    return data;
  }
}

// {
//   "userID":"",
//   "role":0,
//   "muteUntil":0,
//   "joinTime":0,
//   "customInfo":{},
//   "nickName":"",
//   "nameCard":"",
//   "friendRemark":"",
//   "faceUrl":""
// }

==> 3.0.0.tar.gz: lib/models/v2_tim_group_member_full_info.dart <==
/// V2TimGroupMemberFullInfo
///
/// {@category Models}
///
class V2TimGroupMemberFullInfo {
  late String userID;
  late int? role;
  late int? muteUntil;
  late int? joinTime;
  Map<String, String>? customInfo;
  late String? nickName;
  late String? nameCard;
  late String? friendRemark;
  late String? faceUrl;

  V2TimGroupMemberFullInfo({
    required this.userID,
    this.role,
    this.muteUntil,
    this.joinTime,
    this.customInfo,
    this.nickName,
    this.nameCard,
    this.friendRemark,
    this.faceUrl,
  });

  V2TimGroupMemberFullInfo.fromJson(Map<String, dynamic> json) {
    userID = json['userID'];
    role = json['role'];
    muteUntil = json['muteUntil'];
    joinTime = json['joinTime'];
    customInfo = Map<String, String>.from(json['customInfo']);
    nickName = json['nickName'];
    nameCard = json['nameCard'];
    friendRemark = json['friendRemark'];
    faceUrl = json['faceUrl'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['userID'] = this.userID;
    data['role'] = this.role;
    data['muteUntil'] = this.muteUntil;
    data['joinTime'] = this.joinTime;
    data['customInfo'] = this.customInfo;
    data['nickName'] = this.nickName;
    data['nameCard'] = this.nameCard;
    data['friendRemark'] = this.friendRemark;
    data['faceUrl'] = this.faceUrl;
    return data;
  }
}

// {
//   "userID":"",
//   "role":0,
//   "muteUntil":0,
//   "joinTime":0,
//   "customInfo":{},
//   "nickName":"",
//   "nameCard":"",
//   "friendRemark":"",
//   "faceUrl":""
// }
